# Errors

- issue parsing Drug Gene Interaction Database: 
- failed to resolve DisGeNet
- failed to resolve Pathway Commons
- failed to resolve Antibody Registry
- failed to resolve PathBank
- failed to resolve SwissLipids